@@ -100,14 +100,14 @@ rmarkovchain<-function(n,object,...)
 
 #functon to fit a Markov chain by MLE
 
-.mcFitMle<-function(stringchar,byrow)
-{
-  initialMatr<-createSequenceMatrix(stringchar=stringchar,toRowProbs=TRUE)
-  outMc<-new("markovchain", transitionMatrix=initialMatr,name="MLE Fit")
-  if(byrow==FALSE) outMc<-t(outMc)
-  out<-list(estimate=outMc)
-  return(out)
-}
+# .mcFitMle<-function(stringchar,byrow)
+# {
+#   initialMatr<-createSequenceMatrix(stringchar=stringchar,toRowProbs=TRUE)
+#   outMc<-new("markovchain", transitionMatrix=initialMatr,name="MLE Fit")
+#   if(byrow==FALSE) outMc<-t(outMc)
+#   out<-list(estimate=outMc)
+#   return(out)
+# }
 
 
 #function to fit a DTMC with Laplacian Smoother
@@ -135,79 +135,79 @@ rmarkovchain<-function(n,object,...)
 
 
 #given a sting of characters, returns the associate one step transition matrix
-.bootstrapCharacterSequences<-function(stringchar, n, size=length(stringchar))
-{
-  contingencyMatrix<-createSequenceMatrix(stringchar=stringchar)
-  samples<-list()
-  itemset<-rownames(contingencyMatrix)
-  for(i in 1:n) #cicle to fill the samples
-  {
-    charseq<-character()
-    char<-sample(x=itemset,size=1)
-    charseq<-c(charseq,char)
-    for(j in 2:size) #cicle to define the element in a list
-    {
-      probsVector<-contingencyMatrix[which(rownames(contingencyMatrix)==char),]
-      char<-sample(x=itemset,size=1, replace=TRUE,prob=probsVector)
-      charseq<-c(charseq,char)
-    }
-    samples[[length(samples)+1]]<-charseq #increase the list
-  }
-  return(samples)
-}
+# .bootstrapCharacterSequences<-function(stringchar, n, size=length(stringchar))
+# {
+#   contingencyMatrix<-createSequenceMatrix(stringchar=stringchar)
+#   samples<-list()
+#   itemset<-rownames(contingencyMatrix)
+#   for(i in 1:n) #cicle to fill the samples
+#   {
+#     charseq<-character()
+#     char<-sample(x=itemset,size=1)
+#     charseq<-c(charseq,char)
+#     for(j in 2:size) #cicle to define the element in a list
+#     {
+#       probsVector<-contingencyMatrix[which(rownames(contingencyMatrix)==char),]
+#       char<-sample(x=itemset,size=1, replace=TRUE,prob=probsVector)
+#       charseq<-c(charseq,char)
+#     }
+#     samples[[length(samples)+1]]<-charseq #increase the list
+#   }
+#   return(samples)
+# }
 
 
-.fromBoot2Estimate<-function(listMatr)
-{
-  sampleSize<-length(listMatr)
-  matrDim<-nrow(listMatr[[1]])
-  #create the estimate output
-  matrMean<-zeros(matrDim)
-  matrSd<-zeros(matrDim)
-  #create the sample output
-  for(i in 1:matrDim) #move by row
-  {
-    for(j in 1:matrDim) #move by cols
-    {
-      probsEstimated<-numeric()
-      #fill the probs
-      for(k in 1:sampleSize) probsEstimated<-c(probsEstimated,listMatr[[k]][i,j])
-      muCell<-mean(probsEstimated)
-      sdCell<-sd(probsEstimated)
-      matrMean[i,j]<-muCell
-      matrSd[i,j]<-sdCell
-    }
-  }
-	out<-list(estMu=matrMean, estSigma=matrSd)
-    return(out)
-}
-
-
-.mcFitBootStrap<-function(data, nboot=10,byrow=TRUE, parallel=FALSE)
-{
-  #create the list of bootstrap sequence sample
-	theList<-.bootstrapCharacterSequences(stringchar=data, n=nboot)
-	if(!parallel)
-		#convert the list in a probability matrix
-		pmsBootStrapped<-lapply(X=theList, FUN=createSequenceMatrix, toRowProbs=TRUE,sanitize=TRUE)
-		 else {
-		#require(parallel)
-		type <- if(exists("mcfork", mode = "function")) "FORK" else "PSOCK"
-		cores <- getOption("mc.cores", detectCores())
-		cl <- makeCluster(cores, type = type)
-			clusterExport(cl, varlist = c("createSequenceMatrix","zeros"))
-			pmsBootStrapped<-parLapply(cl=cl, X=theList, fun="createSequenceMatrix", toRowProbs=TRUE,sanitize=TRUE)
-		stopCluster(cl)
-	}
- 
-  estimateList<-.fromBoot2Estimate(listMatr=pmsBootStrapped)
-  #from raw to estimate
-  temp<-estimateList$estMu
-  transMatr<-sweep(temp, 1, rowSums(temp), FUN="/")
-  estimate<-new("markovchain",transitionMatrix=transMatr, byrow=byrow, name="BootStrap Estimate")
-  out<-list(estimate=estimate, standardError=estimateList$estSigma,bootStrapSamples=pmsBootStrapped)
-  return(out)
-}
+# .fromBoot2Estimate<-function(listMatr)
+# {
+#   sampleSize<-length(listMatr)
+#   matrDim<-nrow(listMatr[[1]])
+#   #create the estimate output
+#   matrMean<-zeros(matrDim)
+#   matrSd<-zeros(matrDim)
+#   #create the sample output
+#   for(i in 1:matrDim) #move by row
+#   {
+#     for(j in 1:matrDim) #move by cols
+#     {
+#       probsEstimated<-numeric()
+#       #fill the probs
+#       for(k in 1:sampleSize) probsEstimated<-c(probsEstimated,listMatr[[k]][i,j])
+#       muCell<-mean(probsEstimated)
+#       sdCell<-sd(probsEstimated)
+#       matrMean[i,j]<-muCell
+#       matrSd[i,j]<-sdCell
+#     }
+#   }
+# 	out<-list(estMu=matrMean, estSigma=matrSd)
+#     return(out)
+# }
+# 
+# 
+# .mcFitBootStrap<-function(data, nboot=10,byrow=TRUE, parallel=FALSE)
+# {
+#   #create the list of bootstrap sequence sample
+# 	theList<-.bootstrapCharacterSequences(stringchar=data, n=nboot)
+# 	if(!parallel)
+# 		#convert the list in a probability matrix
+# 		pmsBootStrapped<-lapply(X=theList, FUN=createSequenceMatrix, toRowProbs=TRUE,sanitize=TRUE)
+# 		 else {
+# 		#require(parallel)
+# 		type <- if(exists("mcfork", mode = "function")) "FORK" else "PSOCK"
+# 		cores <- getOption("mc.cores", detectCores())
+# 		cl <- makeCluster(cores, type = type)
+# 			clusterExport(cl, varlist = c("createSequenceMatrix","zeros"))
+# 			pmsBootStrapped<-parLapply(cl=cl, X=theList, fun="createSequenceMatrix", toRowProbs=TRUE,sanitize=TRUE)
+# 		stopCluster(cl)
+# 	}
+#  
+#   estimateList<-.fromBoot2Estimate(listMatr=pmsBootStrapped)
+#   #from raw to estimate
+#   temp<-estimateList$estMu
+#   transMatr<-sweep(temp, 1, rowSums(temp), FUN="/")
+#   estimate<-new("markovchain",transitionMatrix=transMatr, byrow=byrow, name="BootStrap Estimate")
+#   out<-list(estimate=estimate, standardError=estimateList$estSigma,bootStrapSamples=pmsBootStrapped)
+#   return(out)
+# }
 
 ###############################################
 #special function for matrices and data.frames#
@@ -292,3 +292,28 @@ markovchainListFit<-function(data,byrow=TRUE, laplacian=0, name) {
   return(out)
 }
 
+#' Return MultinomialWise Confidence intervals.
+#' 
+#' @description Return estimated transition matrix assuming a Multinomial Distribution
+#' 
+#' @param transitionMatrix An estimated transition matrix.
+#' @param countsTransitionMatrix Empirical (conts) transition matrix, on which the \code{transitionMatrix} was performed.
+#' @param confidencelevel confidence interval level.
+#' @return Two matrices containing the confidence intervals.
+#' 
+#' @seealso \code{markovchainFit}
+#' 
+#' @references Constructing two-sided simultaneous confidence intervals 
+#' for multinomial proportions for small counts in a large number of cells. 
+#' Journal of Statistical Software 5(6) (2000)
+#'
+#' @examples 
+#' myletterseq<-sample(x = letters[1:3],size = 120,replace=TRUE)
+#' myMcFit<-markovchainFit(data=myletterseq)
+#' myMultinomialCI=multinomialConfidenceIntervals(transitionMatrix=myMcFit$estimate,countsTransitionMatrix=createSequenceMatrix(stringchar = myletterseq))
+multinomialConfidenceIntervals<-function(transitionMatrix, countsTransitionMatrix, confidencelevel=0.95) {
+  
+  out<-.multinomialCIRcpp(transMat=transitionMatrix, seqMat=countsTransitionMatrix,confidencelevel=confidencelevel)
+  return(out)
+
+  }
