@@ -108,24 +108,57 @@ plot(mcWeather,layout = layout.fruchterman.reingold,main="Weather transition mat
 
 
 ###################################################
-### code chunk number 14: exportImport1
+### code chunk number 14: mcPlotdiagram
+###################################################
+plot(mcWeather, package="diagram", box.size = 0.04)
+
+
+###################################################
+### code chunk number 15: exportImport1
 ###################################################
 mcDf <- as(mcWeather, "data.frame")
 mcNew <- as(mcDf, "markovchain")
 mcDf
 mcIgraph <- as(mcWeather, "igraph")
 
+library(msm)
+Q <- rbind ( c(0, 0.25, 0, 0.25),
+             c(0.166, 0, 0.166, 0.166),
+             c(0, 0.25, 0, 0.25),
+             c(0, 0, 0, 0) )
+cavmsm <- msm(state ~ years, subject = PTNUM, data = cav, qmatrix = Q, death = 4)
+msmMc <- as(cavmsm, "markovchain")
+msmMc
+
+library(etm)
+data(sir.cont)
+sir.cont <- sir.cont[order(sir.cont$id, sir.cont$time), ]
+for (i in 2:nrow(sir.cont)) {
+  if (sir.cont$id[i]==sir.cont$id[i-1]) {
+    if (sir.cont$time[i]==sir.cont$time[i-1]) {
+      sir.cont$time[i-1] <- sir.cont$time[i-1] - 0.5
+    }
+  }
+}
+tra <- matrix(ncol=3,nrow=3,FALSE)
+tra[1, 2:3] <- TRUE
+tra[2, c(1, 3)] <- TRUE
+tr.prob <- etm(sir.cont, c("0", "1", "2"), tra, "cens", 1)
+tr.prob
+etm2mc<-as(tr.prob, "markovchain")
+etm2mc
+
 
 ###################################################
-### code chunk number 15: importExportPlot
+### code chunk number 16: importExportPlot
 ###################################################
 library(igraph)
-importExportGraph<-graph.formula(dataframe++markovchain,markovchain-+igraph,markovchain++matrix,table-+markovchain)
+importExportGraph<-graph.formula(dataframe++markovchain,markovchain-+igraph,markovchain++matrix,table-+markovchain,msm-+markovchain,etm-+markovchain)
 plot(importExportGraph,main="Import - Export from and to markovchain objects")
 
 
 ###################################################
-### code chunk number 16: exportImport2
+### code chunk number 17: exportImport2
 ###################################################
 myMatr<-matrix(c(.1,.8,.1,.2,.6,.2,.3,.4,.3), byrow=TRUE, ncol=3)
 myMc<-as(myMatr, "markovchain")
@@ -133,7 +166,7 @@ myMc
 
 
 ###################################################
-### code chunk number 17: cchcMcList
+### code chunk number 18: cchcMcList
 ###################################################
 stateNames = c("H", "I", "D")
 Q0 <- new("markovchain", states = stateNames, 
@@ -148,26 +181,26 @@ print(mcCCRC)
 
 
 ###################################################
-### code chunk number 18: cchcMcList2
+### code chunk number 19: cchcMcList2
 ###################################################
 mcCCRC[[1]]
 dim(mcCCRC)
 
 
 ###################################################
-### code chunk number 19: conditionalDistr
+### code chunk number 20: conditionalDistr
 ###################################################
 conditionalDistribution(mcWeather, "sunny")
 
 
 ###################################################
-### code chunk number 20: steadyStates
+### code chunk number 21: steadyStates
 ###################################################
 steadyStates(mcWeather)
 
 
 ###################################################
-### code chunk number 21: gamblerRuin
+### code chunk number 22: gamblerRuin
 ###################################################
 gamblerRuinMarkovChain <- function(moneyMax, prob = 0.5) {
   require(matlab)
@@ -189,14 +222,14 @@ steadyStates(mcGR4)
 
 
 ###################################################
-### code chunk number 22: absorbingStates
+### code chunk number 23: absorbingStates
 ###################################################
 absorbingStates(mcGR4)
 absorbingStates(mcWeather)
 
 
 ###################################################
-### code chunk number 23: commclassKernel
+### code chunk number 24: commclassKernel
 ###################################################
 .commclassesKernel <- function(P){
   m <- ncol(P)
@@ -235,7 +268,7 @@ absorbingStates(mcWeather)
 
 
 ###################################################
-### code chunk number 24: renaldoMatrix1
+### code chunk number 25: renaldoMatrix1
 ###################################################
 P <- matlab::zeros(10)
 P[1, c(1, 3)] <- 1/2;
@@ -257,13 +290,13 @@ summary(probMc)
 
 
 ###################################################
-### code chunk number 25: transientStates
+### code chunk number 26: transientStates
 ###################################################
 transientStates(probMc)
 
 
 ###################################################
-### code chunk number 26: probMc2Canonic
+### code chunk number 27: probMc2Canonic
 ###################################################
 probMcCanonic <- canonicForm(probMc)
 probMc
@@ -271,14 +304,14 @@ probMcCanonic
 
 
 ###################################################
-### code chunk number 27: isAccessible
+### code chunk number 28: isAccessible
 ###################################################
 is.accessible(object = probMc, from = "a", to = "c")
 is.accessible(object = probMc, from = "g", to = "c")
 
 
 ###################################################
-### code chunk number 28: periodicity
+### code chunk number 29: periodicity
 ###################################################
 
 E <- matrix(0, nrow = 4, ncol = 4)
@@ -295,7 +328,7 @@ period(mcE)
 
 
 ###################################################
-### code chunk number 29: mathematica9Mc
+### code chunk number 30: mathematica9Mc
 ###################################################
 require(matlab)
 mathematicaMatr <- zeros(5)
@@ -310,19 +343,19 @@ mathematicaMc <- new("markovchain", transitionMatrix = mathematicaMatr,
 
 
 ###################################################
-### code chunk number 30: mathematica9McFig
+### code chunk number 31: mathematica9McFig
 ###################################################
 plot(mathematicaMc, layout = layout.fruchterman.reingold)
 
 
 ###################################################
-### code chunk number 31: mathematica9MC
+### code chunk number 32: mathematica9MC
 ###################################################
 summary(mathematicaMc)
 
 
 ###################################################
-### code chunk number 32: fpTime1 (eval = FALSE)
+### code chunk number 33: fpTime1 (eval = FALSE)
 ###################################################
 ## .firstpassageKernel <- function(P, i, n){
 ##   G <- P
@@ -337,7 +370,7 @@ summary(mathematicaMc)
 
 
 ###################################################
-### code chunk number 33: fpTime2
+### code chunk number 34: fpTime2
 ###################################################
 firstPassagePdF <- firstPassage(object = mcWeather, state = "sunny", 
                                 n = 10)
@@ -345,14 +378,14 @@ firstPassagePdF[3, 3]
 
 
 ###################################################
-### code chunk number 34: simulatingAMarkovChain
+### code chunk number 35: simulatingAMarkovChain
 ###################################################
 weathersOfDays <- rmarkovchain(n = 365, object = mcWeather, t0 = "sunny")
 weathersOfDays[1:30]
 
 
 ###################################################
-### code chunk number 35: simulatingAListOfMarkovChain
+### code chunk number 36: simulatingAListOfMarkovChain
 ###################################################
 patientStates <- rmarkovchain(n = 5, object = mcCCRC, t0 = "H", 
                               include.t0 = TRUE)
@@ -360,7 +393,7 @@ patientStates[1:10,]
 
 
 ###################################################
-### code chunk number 36: fitMcbyMLE
+### code chunk number 37: fitMcbyMLE
 ###################################################
 weatherFittedMLE <- markovchainFit(data = weathersOfDays, method = "mle",
                                  name = "Weather MLE")
@@ -369,7 +402,7 @@ weatherFittedMLE$standardError
 
 
 ###################################################
-### code chunk number 37: fitMcbyLAPLACE
+### code chunk number 38: fitMcbyLAPLACE
 ###################################################
 weatherFittedLAPLACE <- markovchainFit(data = weathersOfDays, 
                                     method = "laplace", laplacian = 0.01,
@@ -378,13 +411,13 @@ weatherFittedLAPLACE$estimate
 
 
 ###################################################
-### code chunk number 38: fitSequenceMatrix
+### code chunk number 39: fitSequenceMatrix
 ###################################################
 createSequenceMatrix(stringchar = weathersOfDays)
 
 
 ###################################################
-### code chunk number 39: fitMcbyBootStrap
+### code chunk number 40: fitMcbyBootStrap
 ###################################################
 weatherFittedBOOT <- markovchainFit(data = weathersOfDays, 
                                     method = "bootstrap", nboot = 100)
@@ -393,7 +426,7 @@ weatherFittedBOOT$standardError
 
 
 ###################################################
-### code chunk number 40: fitMcbyBootStrap (eval = FALSE)
+### code chunk number 41: fitMcbyBootStrap (eval = FALSE)
 ###################################################
 ## weatherFittedBOOTParallel <- markovchainFit(data = weathersOfDays, 
 ##                                     method = "bootstrap", nboot = 10, 
@@ -403,27 +436,35 @@ weatherFittedBOOT$standardError
 
 
 ###################################################
-### code chunk number 41: fitMcbyBootStrap (eval = FALSE)
+### code chunk number 42: fitMcbyBootStrap (eval = FALSE)
 ###################################################
 ## RcppParallel::setNumThreads(4)
 
 
 ###################################################
-### code chunk number 42: fitMcbyMLE
+### code chunk number 43: fitMcbyMLE
 ###################################################
 weatherFittedMLE$logLikelihood
 weatherFittedBOOT$logLikelihood
 
 
 ###################################################
-### code chunk number 43: confint
+### code chunk number 44: confint
 ###################################################
 weatherFittedMLE$confidenceInterval
 weatherFittedBOOT$confidenceInterval
 
 
 ###################################################
-### code chunk number 44: fitMclists
+### code chunk number 45: multinomial
+###################################################
+multinomialConfidenceIntervals(transitionMatrix = 
+        weatherFittedMLE$estimate@transitionMatrix, 
+        countsTransitionMatrix = createSequenceMatrix(weathersOfDays))
+
+
+###################################################
+### code chunk number 46: fitMclists
 ###################################################
 data(holson)
 singleMc<-markovchainFit(data=holson[,2:12],name="holson")
@@ -432,26 +473,26 @@ mcListFit$estimate[[1]]
 
 
 ###################################################
-### code chunk number 45: markovchainPredict
+### code chunk number 47: markovchainPredict
 ###################################################
 predict(object = weatherFittedMLE$estimate, newdata = c("cloudy", "sunny"),
         n.ahead = 3)
 
 
 ###################################################
-### code chunk number 46: markovchainListPredict
+### code chunk number 48: markovchainListPredict
 ###################################################
 predict(mcCCRC, newdata = c("H", "H"), n.ahead = 5)
 
 
 ###################################################
-### code chunk number 47: markovchainListPredict2
+### code chunk number 49: markovchainListPredict2
 ###################################################
 predict(mcCCRC, newdata = c("H", "H"), n.ahead = 5, continue = TRUE)
 
 
 ###################################################
-### code chunk number 48: weatPred1
+### code chunk number 50: weatPred1
 ###################################################
 
 mcWP <- new("markovchain", states = c("rainy", "nice", "snowy"),
@@ -461,7 +502,7 @@ mcWP <- new("markovchain", states = c("rainy", "nice", "snowy"),
 
 
 ###################################################
-### code chunk number 49: weatPred2
+### code chunk number 51: weatPred2
 ###################################################
 W0 <- t(as.matrix(c(0, 1, 0)))
 W1 <- W0 * mcWP; W1
@@ -472,21 +513,21 @@ W3 <- W0 * (mcWP ^ 3); W3
 
 
 ###################################################
-### code chunk number 50: weatPred3
+### code chunk number 52: weatPred3
 ###################################################
 W7 <- W0 * (mcWP ^ 7)
 W7
 
 
 ###################################################
-### code chunk number 51: weatPred4
+### code chunk number 53: weatPred4
 ###################################################
 q <- steadyStates(mcWP)
 q
 
 
 ###################################################
-### code chunk number 52: weatPred5
+### code chunk number 54: weatPred5
 ###################################################
 R0 <- t(as.matrix(c(1, 0, 0)))
 R7 <- R0 * (mcWP ^ 7); R7
@@ -496,27 +537,27 @@ S7 <- S0 * (mcWP ^ 7); S7
 
 
 ###################################################
-### code chunk number 53: Alofi1
+### code chunk number 55: Alofi1
 ###################################################
 data("rain", package = "markovchain")
 table(rain$rain)
 
 
 ###################################################
-### code chunk number 54: Alofi2
+### code chunk number 56: Alofi2
 ###################################################
 mcAlofi <- markovchainFit(data = rain$rain, name = "Alofi MC")$estimate
 mcAlofi
 
 
 ###################################################
-### code chunk number 55: Alofi3
+### code chunk number 57: Alofi3
 ###################################################
 steadyStates(mcAlofi)
 
 
 ###################################################
-### code chunk number 56: ratings1
+### code chunk number 58: ratings1
 ###################################################
 
 rc <- c("AAA", "AA", "A", "BBB", "BB", "B", "CCC", "D")
@@ -532,7 +573,7 @@ creditMatrix <- matrix(c(90.81, 8.33, 0.68, 0.06, 0.08, 0.02, 0.01, 0.01,
 
 
 ###################################################
-### code chunk number 57: ratings2
+### code chunk number 59: ratings2
 ###################################################
 creditMc <- new("markovchain", transitionMatrix = creditMatrix, 
                 name = "S&P Matrix")
@@ -540,7 +581,7 @@ absorbingStates(creditMc)
 
 
 ###################################################
-### code chunk number 58: economicAnalysis1
+### code chunk number 60: economicAnalysis1
 ###################################################
 statesNames <- c("customer", "non customer")
 P <- zeros(2); P[1, 1] <- .9; P[1, 2] <- .1; P[2, 2] <- .95; P[2, 1] <- .05;
@@ -550,20 +591,20 @@ M <- zeros(2); M[1, 1] <- -20; M[1, 2] <- -30; M[2, 1] <- -40; M[2, 2] <- 0
 
 
 ###################################################
-### code chunk number 59: economicAnalysis2
+### code chunk number 61: economicAnalysis2
 ###################################################
 c1 <- 100 + conditionalDistribution(mcP, state = "customer") %*% M[1,]
 c2 <- 0 + conditionalDistribution(mcP, state = "non customer") %*% M[2,]
 
 
 ###################################################
-### code chunk number 60: economicAnalysis3
+### code chunk number 62: economicAnalysis3
 ###################################################
 as.numeric((c(1, 0)* mcP ^ 5) %*% (as.vector(c(c1, c2))))
 
 
 ###################################################
-### code chunk number 61: bonusMalus1
+### code chunk number 63: bonusMalus1
 ###################################################
 
 getBonusMalusMarkovChain <- function(lambda)
@@ -594,20 +635,20 @@ getBonusMalusMarkovChain <- function(lambda)
 
 
 ###################################################
-### code chunk number 62: bonusMalus2
+### code chunk number 64: bonusMalus2
 ###################################################
 bmMc <- getBonusMalusMarkovChain(0.05)
 as.numeric(steadyStates(bmMc))
 
 
 ###################################################
-### code chunk number 63: bonusMalus3
+### code chunk number 65: bonusMalus3
 ###################################################
 sum(as.numeric(steadyStates(bmMc)) * c(0.5, 0.7, 0.9, 1, 1.25))
 
 
 ###################################################
-### code chunk number 64: healthIns1
+### code chunk number 66: healthIns1
 ###################################################
 
 mcHI <- new("markovchain", states = c("active", "disable", "withdrawn", 
@@ -620,7 +661,7 @@ benefitVector <- as.matrix(c(0, 0, 500, 1000))
 
 
 ###################################################
-### code chunk number 65: healthIns2
+### code chunk number 67: healthIns2
 ###################################################
 T0 <- t(as.matrix(c(1, 0, 0, 0)))
 T1 <- T0 * mcHI
@@ -629,7 +670,7 @@ T3 <- T2 * mcHI
 
 
 ###################################################
-### code chunk number 66: healthIns3
+### code chunk number 68: healthIns3
 ###################################################
 PVFB <- T0 %*% benefitVector * 1.05 ^ -0 + 
   T1 %*% benefitVector * 1.05 ^ -1+
@@ -637,13 +678,13 @@ PVFB <- T0 %*% benefitVector * 1.05 ^ -0 +
 
 
 ###################################################
-### code chunk number 67: healthIns4
+### code chunk number 69: healthIns4
 ###################################################
 P <- PVFB / (T0[1] * 1.05 ^- 0 + T1[1] * 1.05 ^ -1 + T2[1] * 1.05 ^ -2)
 
 
 ###################################################
-### code chunk number 68: healthIns5
+### code chunk number 70: healthIns5
 ###################################################
 PVFB <- T2 %*% benefitVector * 1.05 ^ -1 + T3 %*% benefitVector * 1.05 ^ -2
 PVFP <- P*(T1[1] * 1.05 ^ -0 + T2[1] * 1.05 ^ -1)
@@ -652,7 +693,7 @@ V
 
 
 ###################################################
-### code chunk number 69: blandenEtAlii
+### code chunk number 71: blandenEtAlii
 ###################################################
 data("blanden")
 mobilityMc <- as(blanden, "markovchain")
@@ -660,26 +701,26 @@ mobilityMc
 
 
 ###################################################
-### code chunk number 70: blandenEtAlii2
+### code chunk number 72: blandenEtAlii2
 ###################################################
 plot(mobilityMc, main = '1970 mobility',vertex.label.cex = 2,
 		layout = layout.fruchterman.reingold)
 
 
 ###################################################
-### code chunk number 71: blandenEtAlii3
+### code chunk number 73: blandenEtAlii3
 ###################################################
 round(steadyStates(mobilityMc), 2)
 
 
 ###################################################
-### code chunk number 72: preproglucacon1
+### code chunk number 74: preproglucacon1
 ###################################################
 data("preproglucacon", package = "markovchain")
 
 
 ###################################################
-### code chunk number 73: preproglucacon2
+### code chunk number 75: preproglucacon2
 ###################################################
 mcProtein <- markovchainFit(preproglucacon$preproglucacon, 
                           name = "Preproglucacon MC")$estimate
@@ -687,7 +728,7 @@ mcProtein
 
 
 ###################################################
-### code chunk number 74: epid1
+### code chunk number 76: epid1
 ###################################################
 craigSendiMatr <- matrix(c(682, 33, 25,
               154, 64, 47,
@@ -702,14 +743,14 @@ mcM6
 
 
 ###################################################
-### code chunk number 75: epid2
+### code chunk number 77: epid2
 ###################################################
 eig <- eigen(mcM6@transitionMatrix)
 D <- diag(eig$values)
 
 
 ###################################################
-### code chunk number 76: epid3
+### code chunk number 78: epid3
 ###################################################
 V <- eig$vectors 
 V %*% D %*% solve(V)
