@@ -119,12 +119,25 @@ List _mcFitMle(CharacterVector stringchar, bool byrow, double confidencelevel) {
   double marginOfError, lowerEndpoint, upperEndpoint;
   for(int i = 0; i < nrows; i ++) {
     for(int j = 0; j < ncols; j ++) {
-      standardError(i, j) = initialMatr(i, j) / sqrt(freqMatr(i, j));
-      marginOfError = zscore * standardError(i, j);
-      lowerEndpoint = initialMatr(i, j) - marginOfError;
-      upperEndpoint = initialMatr(i, j) + marginOfError;
-      lowerEndpointMatr(i,j) = (lowerEndpoint > 1.0) ? 1.0 : ((0.0 > lowerEndpoint) ? 0.0 : lowerEndpoint);
-      upperEndpointMatr(i,j) = (upperEndpoint > 1.0) ? 1.0 : ((0.0 > upperEndpoint) ? 0.0 : upperEndpoint);
+      if(freqMatr(i,j) == 0) {
+        bool notrans = true;
+        for(int k = 0; k < ncols; k ++) {
+          if(freqMatr(i,k) != 0) {
+            standardError(i, j) = lowerEndpointMatr(i,j) = upperEndpointMatr(i,j) = 0;
+            notrans = false;
+            break;
+          }
+        }
+        if(notrans) 
+          standardError(i, j) = lowerEndpointMatr(i,j) = upperEndpointMatr(i,j) = 1;
+      } else {
+        standardError(i, j) = initialMatr(i, j) / sqrt(freqMatr(i, j));
+        marginOfError = zscore * standardError(i, j);
+        lowerEndpoint = initialMatr(i, j) - marginOfError;
+        upperEndpoint = initialMatr(i, j) + marginOfError;
+        lowerEndpointMatr(i,j) = (lowerEndpoint > 1.0) ? 1.0 : ((0.0 > lowerEndpoint) ? 0.0 : lowerEndpoint);
+        upperEndpointMatr(i,j) = (upperEndpoint > 1.0) ? 1.0 : ((0.0 > upperEndpoint) ? 0.0 : upperEndpoint);
+      }
     }
   }
   standardError.attr("dimnames") = upperEndpointMatr.attr("dimnames") 
